==> zio-aws-servicecatalog_2.13-5.17.112.1-sources.jar: zio/aws/servicecatalog/model/UpdatePortfolioShareRequest.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.servicecatalog.model.primitives.{
  NullableBoolean,
  AccountId,
  Id,
  AcceptLanguage
}
import scala.jdk.CollectionConverters._
final case class UpdatePortfolioShareRequest(
    acceptLanguage: Option[AcceptLanguage] = None,
    portfolioId: Id,
    accountId: Option[AccountId] = None,
    organizationNode: Option[zio.aws.servicecatalog.model.OrganizationNode] =
      None,
    shareTagOptions: Option[NullableBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest = {
    import UpdatePortfolioShareRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest
      .builder()
      .optionallyWith(
        acceptLanguage.map(value =>
          AcceptLanguage.unwrap(value): java.lang.String
        )
      )(_.acceptLanguage)
      .portfolioId(Id.unwrap(portfolioId): java.lang.String)
      .optionallyWith(
        accountId.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.accountId)
      .optionallyWith(organizationNode.map(value => value.buildAwsValue()))(
        _.organizationNode
      )
      .optionallyWith(
        shareTagOptions.map(value =>
          NullableBoolean.unwrap(value): java.lang.Boolean
        )
      )(_.shareTagOptions)
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.UpdatePortfolioShareRequest.ReadOnly =
    zio.aws.servicecatalog.model.UpdatePortfolioShareRequest
      .wrap(buildAwsValue())
}
object UpdatePortfolioShareRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.UpdatePortfolioShareRequest =
      zio.aws.servicecatalog.model.UpdatePortfolioShareRequest(
        acceptLanguage.map(value => value),
        portfolioId,
        accountId.map(value => value),
        organizationNode.map(value => value.asEditable),
        shareTagOptions.map(value => value)
      )
    def acceptLanguage: Option[AcceptLanguage]
    def portfolioId: Id
    def accountId: Option[AccountId]
    def organizationNode
        : Option[zio.aws.servicecatalog.model.OrganizationNode.ReadOnly]
    def shareTagOptions: Option[NullableBoolean]
    def getAcceptLanguage: ZIO[Any, AwsError, AcceptLanguage] =
      AwsError.unwrapOptionField("acceptLanguage", acceptLanguage)
    def getPortfolioId: ZIO[Any, Nothing, Id] = ZIO.succeed(portfolioId)
    def getAccountId: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getOrganizationNode: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.OrganizationNode.ReadOnly
    ] = AwsError.unwrapOptionField("organizationNode", organizationNode)
    def getShareTagOptions: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField("shareTagOptions", shareTagOptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest
  ) extends zio.aws.servicecatalog.model.UpdatePortfolioShareRequest.ReadOnly {
    override val acceptLanguage: Option[AcceptLanguage] = scala
      .Option(impl.acceptLanguage())
      .map(value =>
        zio.aws.servicecatalog.model.primitives.AcceptLanguage(value)
      )
    override val portfolioId: Id =
      zio.aws.servicecatalog.model.primitives.Id(impl.portfolioId())
    override val accountId: Option[AccountId] = scala
      .Option(impl.accountId())
      .map(value => zio.aws.servicecatalog.model.primitives.AccountId(value))
    override val organizationNode
        : Option[zio.aws.servicecatalog.model.OrganizationNode.ReadOnly] = scala
      .Option(impl.organizationNode())
      .map(value => zio.aws.servicecatalog.model.OrganizationNode.wrap(value))
    override val shareTagOptions: Option[NullableBoolean] = scala
      .Option(impl.shareTagOptions())
      .map(value =>
        zio.aws.servicecatalog.model.primitives.NullableBoolean(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest
  ): zio.aws.servicecatalog.model.UpdatePortfolioShareRequest.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-servicecatalog_2.13-5.17.155.2-sources.jar: zio/aws/servicecatalog/model/UpdatePortfolioShareRequest.scala <==
package zio.aws.servicecatalog.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.aws.servicecatalog.model.primitives.{
  NullableBoolean,
  AccountId,
  Id,
  AcceptLanguage
}
import scala.jdk.CollectionConverters._
final case class UpdatePortfolioShareRequest(
    acceptLanguage: Option[AcceptLanguage] = None,
    portfolioId: Id,
    accountId: Option[AccountId] = None,
    organizationNode: Option[zio.aws.servicecatalog.model.OrganizationNode] =
      None,
    shareTagOptions: Option[NullableBoolean] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest = {
    import UpdatePortfolioShareRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest
      .builder()
      .optionallyWith(
        acceptLanguage.map(value =>
          AcceptLanguage.unwrap(value): java.lang.String
        )
      )(_.acceptLanguage)
      .portfolioId(Id.unwrap(portfolioId): java.lang.String)
      .optionallyWith(
        accountId.map(value => AccountId.unwrap(value): java.lang.String)
      )(_.accountId)
      .optionallyWith(organizationNode.map(value => value.buildAwsValue()))(
        _.organizationNode
      )
      .optionallyWith(shareTagOptions.map(value => value: java.lang.Boolean))(
        _.shareTagOptions
      )
      .build()
  }
  def asReadOnly
      : zio.aws.servicecatalog.model.UpdatePortfolioShareRequest.ReadOnly =
    zio.aws.servicecatalog.model.UpdatePortfolioShareRequest
      .wrap(buildAwsValue())
}
object UpdatePortfolioShareRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.servicecatalog.model.UpdatePortfolioShareRequest =
      zio.aws.servicecatalog.model.UpdatePortfolioShareRequest(
        acceptLanguage.map(value => value),
        portfolioId,
        accountId.map(value => value),
        organizationNode.map(value => value.asEditable),
        shareTagOptions.map(value => value)
      )
    def acceptLanguage: Option[AcceptLanguage]
    def portfolioId: Id
    def accountId: Option[AccountId]
    def organizationNode
        : Option[zio.aws.servicecatalog.model.OrganizationNode.ReadOnly]
    def shareTagOptions: Option[NullableBoolean]
    def getAcceptLanguage: ZIO[Any, AwsError, AcceptLanguage] =
      AwsError.unwrapOptionField("acceptLanguage", acceptLanguage)
    def getPortfolioId: ZIO[Any, Nothing, Id] = ZIO.succeed(portfolioId)
    def getAccountId: ZIO[Any, AwsError, AccountId] =
      AwsError.unwrapOptionField("accountId", accountId)
    def getOrganizationNode: ZIO[
      Any,
      AwsError,
      zio.aws.servicecatalog.model.OrganizationNode.ReadOnly
    ] = AwsError.unwrapOptionField("organizationNode", organizationNode)
    def getShareTagOptions: ZIO[Any, AwsError, NullableBoolean] =
      AwsError.unwrapOptionField("shareTagOptions", shareTagOptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest
  ) extends zio.aws.servicecatalog.model.UpdatePortfolioShareRequest.ReadOnly {
    override val acceptLanguage: Option[AcceptLanguage] = scala
      .Option(impl.acceptLanguage())
      .map(value =>
        zio.aws.servicecatalog.model.primitives.AcceptLanguage(value)
      )
    override val portfolioId: Id =
      zio.aws.servicecatalog.model.primitives.Id(impl.portfolioId())
    override val accountId: Option[AccountId] = scala
      .Option(impl.accountId())
      .map(value => zio.aws.servicecatalog.model.primitives.AccountId(value))
    override val organizationNode
        : Option[zio.aws.servicecatalog.model.OrganizationNode.ReadOnly] = scala
      .Option(impl.organizationNode())
      .map(value => zio.aws.servicecatalog.model.OrganizationNode.wrap(value))
    override val shareTagOptions: Option[NullableBoolean] =
      scala.Option(impl.shareTagOptions()).map(value => value: NullableBoolean)
  }
  def wrap(
      impl: software.amazon.awssdk.services.servicecatalog.model.UpdatePortfolioShareRequest
  ): zio.aws.servicecatalog.model.UpdatePortfolioShareRequest.ReadOnly =
    new Wrapper(impl)
}
